@@ -135,6 +135,10 @@
 #'       Returns `TRUE` if the cache contains the key, otherwise
 #'       `FALSE`.
 #'     }
+#'     \item{`remove(key)`}{
+#'       Removes `key` from the cache, if it exists in the cache. If the key is
+#'       not in the cache, this does nothing.
+#'     }
 #'     \item{`size()`}{
 #'       Returns the number of items currently in the cache.
 #'     }
@@ -199,6 +203,11 @@ cache_disk <- function(
   warn_ref_objects = FALSE,
   logfile = NULL
 ) {
+  # ============================================================================
+  # Constants
+  # ============================================================================
+  PRUNE_THROTTLE_TIME_LIMIT <- 5
+
   # ============================================================================
   # Logging
   # ============================================================================
@@ -426,7 +435,7 @@ cache_disk <- function(
       info <- info[!rm_idx, ]
     }
 
-    prune_last_time_ <- as.numeric(current_time)
+    prune_last_time_ <<- as.numeric(current_time)
 
     invisible(TRUE)
   }
@@ -468,7 +477,7 @@ cache_disk <- function(
     file.remove(dir(dir_, "\\.rds$", full.names = TRUE))
     # Next remove dir recursively, including sentinel file.
     unlink(dir_, recursive = TRUE)
-    destroyed_ <- TRUE
+    destroyed_ <<- TRUE
     invisible(TRUE)
   }
 
@@ -477,7 +486,7 @@ cache_disk <- function(
         file.exists(file.path(dir_, "__destroyed__")))
     {
       # It's possible for another process to destroy a shared cache directory
-      destroyed_ <- TRUE
+      destroyed_ <<- TRUE
     }
 
     if (throw) {
@@ -510,13 +519,13 @@ cache_disk <- function(
   # future, the behavior may be customizable.
   prune_throttled_ <- function() {
     # Count the number of times prune() has been called.
-    prune_throttle_counter_ <- prune_throttle_counter_ + 1
+    prune_throttle_counter_ <<- prune_throttle_counter_ + 1
 
-    if (prune_throttle_counter_ > prune_rate_ ||
-        prune_last_time_ - as.numeric(Sys.time()) > 5)
+    if (prune_throttle_counter_ >= prune_rate_ ||
+        as.numeric(Sys.time()) - prune_last_time_ > PRUNE_THROTTLE_TIME_LIMIT)
     {
       prune()
-      prune_throttle_counter_ <- 0
+      prune_throttle_counter_ <<- 0
     }
   }
 
